@@ -3,12 +3,9 @@
 from __future__ import print_function
 
 from simple_event_bus.core import EVENT, EVENT_TYPE, AsyncEventBus, Event, EventBus
-from simple_event_bus.errors import (
-    ErrorEventType,
-    EventBusBaseError,
-    EVENTNameError,
-    MultiParamFunctionError,
-    NotAsyncFunction,
+from simple_event_bus.event_source import (
+    run_simple_event_source,
+    run_simple_event_source_async,
 )
 
 from ._version import get_versions
@@ -16,6 +13,7 @@ from ._version import get_versions
 __author__ = "AngusWG"
 __email__ = "z740713651@outlook.com"
 __version__ = get_versions()["version"]
+
 del get_versions
 
 __all__ = [
@@ -26,10 +24,7 @@ __all__ = [
     Event,
     EventBus,
     AsyncEventBus,
-    # exception
-    EventBusBaseError,
-    NotAsyncFunction,
-    ErrorEventType,
-    EVENTNameError,
-    MultiParamFunctionError,
+    # event_source
+    run_simple_event_source,
+    run_simple_event_source_async,
 ]
